/* This file is part of GNU Pies.
   Copyright (C) 2015-2019 Sergey Poznyakoff

   GNU Pies is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   GNU Pies is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with GNU Pies.  If not, see <http://www.gnu.org/licenses/>. */

#include <config.h>
#include <stdlib.h>
#include <grecs.h>
#include <sysexits.h>

struct grecs_txtacc *pp_cmd;

void
pp_add_option (const char *opt, const char *arg)
{
  if (!DEFAULT_PREPROCESSOR)
    {
      grecs_error (NULL, 0, _("no preprocessor configured"));
      exit (EX_CONFIG);
    }
  if (!pp_cmd)
    {
      pp_cmd = grecs_txtacc_create ();
      grecs_txtacc_grow_string (pp_cmd, DEFAULT_PREPROCESSOR);
    }
  grecs_txtacc_grow_char (pp_cmd, ' ');
  grecs_txtacc_grow_string (pp_cmd, opt);
  
  if (arg)
    {
      grecs_txtacc_grow_char (pp_cmd, '\'');
      for (; *arg; ++arg)
	{
	  if (*arg == '\'')
	    grecs_txtacc_grow_string (pp_cmd, "'\\''");
	  else
	    grecs_txtacc_grow (pp_cmd, arg, 1);
	}
      grecs_txtacc_grow_char (pp_cmd, '\'');
    }
}

char *
pp_command_line (void)
{
  char *ret;
  
  if (!DEFAULT_PREPROCESSOR)
    return NULL;
  
  if (!pp_cmd)
    {
      pp_cmd = grecs_txtacc_create ();
      grecs_txtacc_grow_string (pp_cmd, DEFAULT_PREPROCESSOR);
    }
  grecs_txtacc_grow_char (pp_cmd, 0);
  ret = grecs_txtacc_finish (pp_cmd, 1);
  grecs_txtacc_free (pp_cmd);
  pp_cmd = NULL;
  return ret;
}
